@@ -78,8 +78,14 @@ class ChuangmiPlugStatus(DeviceStatus):
             return float(self.data["load_power"])
         return None
 
-    @property
+    @property  # type: ignore
+    @deprecated("Use led()")
     def wifi_led(self) -> Optional[bool]:
+        """True if the wifi led is turned on."""
+        return self.led
+
+    @property
+    def led(self) -> Optional[bool]:
         """True if the wifi led is turned on."""
         if "wifi_led" in self.data and self.data["wifi_led"] is not None:
             return self.data["wifi_led"] == "on"
@@ -142,6 +148,7 @@ class ChuangmiPlug(Device):
         """Power off."""
         return self.send("set_usb_off")
 
+    @deprecated("Use set_led instead of set_wifi_led")
     @command(
         click.argument("wifi_led", type=bool),
         default_output=format_output(
@@ -152,63 +159,17 @@ class ChuangmiPlug(Device):
     )
     def set_wifi_led(self, wifi_led: bool):
         """Set the wifi led on/off."""
+        self.set_led(wifi_led)
+
+    @command(
+        click.argument("wifi_led", type=bool),
+        default_output=format_output(
+            lambda wifi_led: "Turning on LED" if wifi_led else "Turning off LED"
+        ),
+    )
+    def set_led(self, wifi_led: bool):
+        """Set the led on/off."""
         if wifi_led:
             return self.send("set_wifi_led", ["on"])
         else:
             return self.send("set_wifi_led", ["off"])
-
-
-@deprecated(
-    "This device class is deprecated. Please use the ChuangmiPlug "
-    "class in future and select a model by parameter 'model'."
-)
-class Plug(ChuangmiPlug):
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-        *,
-        model: str = None
-    ) -> None:
-        super().__init__(
-            ip, token, start_id, debug, lazy_discover, model=MODEL_CHUANGMI_PLUG_M1
-        )
-
-
-@deprecated(
-    "This device class is deprecated. Please use the ChuangmiPlug "
-    "class in future and select a model by parameter 'model'."
-)
-class PlugV1(ChuangmiPlug):
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-    ) -> None:
-        super().__init__(
-            ip, token, start_id, debug, lazy_discover, model=MODEL_CHUANGMI_PLUG_V1
-        )
-
-
-@deprecated(
-    "This device class is deprecated. Please use the ChuangmiPlug "
-    "class in future and select a model by parameter 'model'."
-)
-class PlugV3(ChuangmiPlug):
-    def __init__(
-        self,
-        ip: str = None,
-        token: str = None,
-        start_id: int = 0,
-        debug: int = 0,
-        lazy_discover: bool = True,
-    ) -> None:
-        super().__init__(
-            ip, token, start_id, debug, lazy_discover, model=MODEL_CHUANGMI_PLUG_V3
-        )
