@@ -3,7 +3,7 @@ import logging
 import warnings
 from enum import Enum
 from pprint import pformat as pf
-from typing import Any, List, Optional  # noqa: F401
+from typing import Any, Dict, List, Optional  # noqa: F401
 
 import click
 
@@ -57,6 +57,7 @@ class Device(metaclass=DeviceGroupMeta):
 
     retry_count = 3
     timeout = 5
+    _mappings: Dict[str, Any] = {}
     _supported_models: List[str] = []
 
     def __init__(
@@ -157,7 +158,7 @@ class Device(metaclass=DeviceGroupMeta):
             if devinfo.model not in self.supported_models and cls not in bases:
                 _LOGGER.warning(
                     "Found an unsupported model '%s' for class '%s'. If this is working for you, please open an issue at https://github.com/rytilahti/python-miio/",
-                    self.model,
+                    devinfo.model,
                     cls,
                 )
 
@@ -167,6 +168,13 @@ class Device(metaclass=DeviceGroupMeta):
                 "Unable to request miIO.info from the device"
             ) from ex
 
+    @property
+    def device_id(self) -> int:
+        """Return device id (did), if available."""
+        if not self._protocol._device_id:
+            self.send_handshake()
+        return int.from_bytes(self._protocol._device_id, byteorder="big")
+
     @property
     def raw_id(self) -> int:
         """Return the last used protocol sequence id."""
@@ -175,7 +183,7 @@ class Device(metaclass=DeviceGroupMeta):
     @property
     def supported_models(self) -> List[str]:
         """Return a list of supported models."""
-        return self._supported_models
+        return list(self._mappings.keys()) or self._supported_models
 
     @property
     def model(self) -> str:
