@@ -9,16 +9,6 @@ from .subdevice import SubDevice
 class LightBulb(SubDevice):
     """Base class for subdevice light bulbs."""
 
-    @command()
-    def update(self):
-        """Update all device properties."""
-        self._props["brightness"] = self.send("get_bright").pop()
-        self._props["color_temp"] = self.send("get_ct").pop()
-        if self._props["brightness"] > 0 and self._props["brightness"] <= 100:
-            self._props["status"] = "on"
-        else:
-            self._props["status"] = "off"
-
     @command()
     def on(self):
         """Turn bulb on."""
