@@ -3,7 +3,7 @@
 import logging
 import os
 import sys
-from typing import Dict
+from typing import Callable, Dict, List
 
 import click
 import yaml
@@ -37,6 +37,8 @@ SUPPORTED_MODELS = [
     GATEWAY_MODEL_AC_V3,
 ]
 
+GatewayCallback = Callable[[str, str], None]
+
 
 class GatewayException(DeviceException):
     """Exception for the Xioami Gateway communication."""
@@ -99,6 +101,7 @@ class Gateway(Device):
         lazy_discover: bool = True,
         *,
         model: str = None,
+        push_server=None,
     ) -> None:
         super().__init__(ip, token, start_id, debug, lazy_discover, model=model)
 
@@ -109,7 +112,13 @@ class Gateway(Device):
         self._devices: Dict[str, SubDevice] = {}
         self._info = None
         self._subdevice_model_map = None
-        self._did = None
+
+        self._push_server = push_server
+        self._event_ids: List[str] = []
+        self._registered_callbacks: Dict[str, GatewayCallback] = {}
+
+        if self._push_server is not None:
+            self._push_server.register_miio_device(self, self.push_callback)
 
     def _get_unknown_model(self):
         for model_info in self.subdevice_model_map:
@@ -210,6 +219,14 @@ class Gateway(Device):
 
         return self._devices
 
+    def _get_device_by_did(self, device_dict, device_did):
+        """Get a device by its did from a device dict."""
+        for device in device_dict:
+            if device["did"] == device_did:
+                return device
+
+        return None
+
     @command()
     def get_devices_from_dict(self, device_dict):
         """Get SubDevices from a dict containing at least "mac", "did", "parent_id" and
@@ -222,34 +239,40 @@ class Gateway(Device):
         self._devices = {}
 
         # find the gateway
-        for device in device_dict:
-            if device["mac"] == self.mac:
-                self._did = device["did"]
-                break
-
-        # check if the gateway is found
-        if self._did is None:
+        gateway = self._get_device_by_did(device_dict, str(self.device_id))
+        if gateway is None:
             _LOGGER.error(
-                "Could not find gateway with ip '%s', mac '%s', model '%s' in the cloud device list response",
+                "Could not find gateway with ip '%s', mac '%s', did '%i', model '%s' in the cloud device list response",
                 self.ip,
                 self.mac,
+                self.device_id,
+                self.model,
+            )
+            return self._devices
+
+        if gateway["mac"] != self.mac:
+            _LOGGER.error(
+                "Mac and device id of gateway with ip '%s', mac '%s', did '%i', model '%s' did not match in the cloud device list response",
+                self.ip,
+                self.mac,
+                self.device_id,
                 self.model,
             )
             return self._devices
 
         # find the subdevices belonging to this gateway
         for device in device_dict:
-            if device.get("parent_id") == self._did:
-                # Match 'model' to get the type_id
-                model_info = self.match_zigbee_model(device["model"], device["did"])
+            if device.get("parent_id") != str(self.device_id):
+                continue
 
-                # Extract discovered information
-                dev_info = SubDeviceInfo(
-                    device["did"], model_info["type_id"], -1, -1, -1
-                )
+            # Match 'model' to get the type_id
+            model_info = self.match_zigbee_model(device["model"], device["did"])
 
-                # Setup the device
-                self.setup_device(dev_info, model_info)
+            # Extract discovered information
+            dev_info = SubDeviceInfo(device["did"], model_info["type_id"], -1, -1, -1)
+
+            # Setup the device
+            self.setup_device(dev_info, model_info)
 
         return self._devices
 
@@ -387,3 +410,43 @@ class Gateway(Device):
             raise GatewayException(
                 "Got an exception while getting gateway illumination"
             ) from ex
+
+    def register_callback(self, id: str, callback: GatewayCallback):
+        """Register a external callback function for updates of this subdevice."""
+        if id in self._registered_callbacks:
+            _LOGGER.error(
+                "A callback with id '%s' was already registed, overwriting previous callback",
+                id,
+            )
+        self._registered_callbacks[id] = callback
+
+    def remove_callback(self, id: str):
+        """Remove a external callback using its id."""
+        self._registered_callbacks.pop(id)
+
+    def gateway_push_callback(self, action: str, params: str):
+        """Callback from the push server regarding the gateway itself."""
+        for callback in self._registered_callbacks.values():
+            callback(action, params)
+
+    def push_callback(self, source_device: str, action: str, params: str):
+        """Callback from the push server."""
+        if source_device == str(self.device_id):
+            self.gateway_push_callback(action, params)
+            return
+
+        if source_device not in self.devices:
+            _LOGGER.error(
+                "'%s' callback from device '%s' not from a known device",
+                action,
+                source_device,
+            )
+            return
+
+        device = self.devices[source_device]
+        device.push_callback(action, params)
+
+    def close(self):
+        """Cleanup all subscribed events and registered callbacks."""
+        if self._push_server is not None:
+            self._push_server.unregister_miio_device(self)
