@@ -10,21 +10,13 @@ from miio.fan_common import FanException, MoveDirection, OperationMode
 MODEL_FAN_P9 = "dmaker.fan.p9"
 MODEL_FAN_P10 = "dmaker.fan.p10"
 MODEL_FAN_P11 = "dmaker.fan.p11"
+MODEL_FAN_P15 = "dmaker.fan.p15"
+MODEL_FAN_P18 = "dmaker.fan.p18"
+MODEL_FAN_P33 = "dmaker.fan.p33"
 MODEL_FAN_1C = "dmaker.fan.1c"
 
 
 MIOT_MAPPING = {
-    MODEL_FAN_1C: {
-        # https://miot-spec.org/miot-spec-v2/instance?type=urn:miot-spec-v2:device:fan:0000A005:dmaker-1c:1
-        "power": {"siid": 2, "piid": 1},
-        "fan_level": {"siid": 2, "piid": 2},
-        "child_lock": {"siid": 3, "piid": 1},
-        "swing_mode": {"siid": 2, "piid": 3},
-        "power_off_time": {"siid": 2, "piid": 10},
-        "buzzer": {"siid": 2, "piid": 11},
-        "light": {"siid": 2, "piid": 12},
-        "mode": {"siid": 2, "piid": 7},
-    },
     MODEL_FAN_P9: {
         # Source https://miot-spec.org/miot-spec-v2/instance?type=urn:miot-spec-v2:device:fan:0000A005:dmaker-p9:1
         "power": {"siid": 2, "piid": 1},
@@ -68,12 +60,48 @@ MIOT_MAPPING = {
         "power_off_time": {"siid": 3, "piid": 1},
         "set_move": {"siid": 6, "piid": 1},
     },
+    MODEL_FAN_P33: {
+        # Source https://miot-spec.org/miot-spec-v2/instance?type=urn:miot-spec-v2:device:fan:0000A005:dmaker-p33:1
+        "power": {"siid": 2, "piid": 1},
+        "fan_level": {"siid": 2, "piid": 2},
+        "mode": {"siid": 2, "piid": 3},
+        "swing_mode": {"siid": 2, "piid": 4},
+        "swing_mode_angle": {"siid": 2, "piid": 5},
+        "fan_speed": {"siid": 2, "piid": 6},
+        "light": {"siid": 4, "piid": 1},
+        "buzzer": {"siid": 5, "piid": 1},
+        # "device_fault": {"siid": 6, "piid": 2},
+        "child_lock": {"siid": 7, "piid": 1},
+        "power_off_time": {"siid": 3, "piid": 1},
+        "set_move": {"siid": 6, "piid": 1},
+    },
+}
+
+
+# These mappings are based on user reports and may not cover all features
+MIOT_MAPPING[MODEL_FAN_P15] = MIOT_MAPPING[MODEL_FAN_P11]  # see #1354
+MIOT_MAPPING[MODEL_FAN_P18] = MIOT_MAPPING[MODEL_FAN_P10]  # see #1341
+
+
+FAN1C_MAPPINGS = {
+    MODEL_FAN_1C: {
+        # https://miot-spec.org/miot-spec-v2/instance?type=urn:miot-spec-v2:device:fan:0000A005:dmaker-1c:1
+        "power": {"siid": 2, "piid": 1},
+        "fan_level": {"siid": 2, "piid": 2},
+        "child_lock": {"siid": 3, "piid": 1},
+        "swing_mode": {"siid": 2, "piid": 3},
+        "power_off_time": {"siid": 2, "piid": 10},
+        "buzzer": {"siid": 2, "piid": 11},
+        "light": {"siid": 2, "piid": 12},
+        "mode": {"siid": 2, "piid": 7},
+    }
 }
 
 SUPPORTED_ANGLES = {
     MODEL_FAN_P9: [30, 60, 90, 120, 150],
     MODEL_FAN_P10: [30, 60, 90, 120, 140],
     MODEL_FAN_P11: [30, 60, 90, 120, 140],
+    MODEL_FAN_P33: [30, 60, 90, 120, 140],
 }
 
 
@@ -231,8 +259,6 @@ class FanStatus1C(DeviceStatus):
 
 class FanMiot(MiotDevice):
     _mappings = MIOT_MAPPING
-    # TODO Fan1C should be merged to FanMiot
-    _supported_models = list(set(MIOT_MAPPING) - {MODEL_FAN_1C})
 
     @command(
         default_output=format_output(
@@ -373,8 +399,8 @@ class FanMiot(MiotDevice):
 
 
 class Fan1C(MiotDevice):
-    mapping = MIOT_MAPPING[MODEL_FAN_1C]
-    _supported_models = [MODEL_FAN_1C]
+    # TODO Fan1C should be merged to FanMiot, or moved into its separate file
+    _mappings = FAN1C_MAPPINGS
 
     def __init__(
         self,
