@@ -1,6 +1,7 @@
 """Dreame Vacuum."""
 
 import logging
+import threading
 from enum import Enum
 from typing import Dict, Optional
 
@@ -8,8 +9,10 @@ import click
 
 from miio.click_common import command, format_output
 from miio.exceptions import DeviceException
+from miio.interfaces import FanspeedPresets, VacuumInterface
 from miio.miot_device import DeviceStatus as DeviceStatusContainer
 from miio.miot_device import MiotDevice, MiotMapping
+from miio.updater import OneShotServer
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -18,7 +21,9 @@ DREAME_1C = "dreame.vacuum.mc1808"
 DREAME_F9 = "dreame.vacuum.p2008"
 DREAME_D9 = "dreame.vacuum.p2009"
 DREAME_Z10_PRO = "dreame.vacuum.p2028"
-
+DREAME_MOP_2_PRO_PLUS = "dreame.vacuum.p2041o"
+DREAME_MOP_2_ULTRA = "dreame.vacuum.p2150a"
+DREAME_MOP_2 = "dreame.vacuum.p2150o"
 
 _DREAME_1C_MAPPING: MiotMapping = {
     # https://home.miot-spec.com/spec/dreame.vacuum.mc1808
@@ -63,6 +68,7 @@ _DREAME_1C_MAPPING: MiotMapping = {
     "reset_sidebrush_life": {"siid": 28, "aiid": 1},
     "move": {"siid": 21, "aiid": 1},
     "play_sound": {"siid": 24, "aiid": 3},
+    "set_voice": {"siid": 24, "aiid": 2},
 }
 
 
@@ -70,6 +76,9 @@ _DREAME_F9_MAPPING: MiotMapping = {
     # https://home.miot-spec.com/spec/dreame.vacuum.p2008
     # https://home.miot-spec.com/spec/dreame.vacuum.p2009
     # https://home.miot-spec.com/spec/dreame.vacuum.p2028
+    # https://home.miot-spec.com/spec/dreame.vacuum.p2041o
+    # https://home.miot-spec.com/spec/dreame.vacuum.p2150a
+    # https://home.miot-spec.com/spec/dreame.vacuum.p2150o
     "battery_level": {"siid": 3, "piid": 1},
     "charging_state": {"siid": 3, "piid": 2},
     "device_fault": {"siid": 2, "piid": 2},
@@ -115,6 +124,9 @@ MIOT_MAPPING: Dict[str, MiotMapping] = {
     DREAME_F9: _DREAME_F9_MAPPING,
     DREAME_D9: _DREAME_F9_MAPPING,
     DREAME_Z10_PRO: _DREAME_F9_MAPPING,
+    DREAME_MOP_2_PRO_PLUS: _DREAME_F9_MAPPING,
+    DREAME_MOP_2_ULTRA: _DREAME_F9_MAPPING,
+    DREAME_MOP_2: _DREAME_F9_MAPPING,
 }
 
 
@@ -184,8 +196,16 @@ def _get_cleaning_mode_enum_class(model):
     """Return cleaning mode enum class for model if found or None."""
     if model == DREAME_1C:
         return CleaningModeDreame1C
-    elif model in [DREAME_F9, DREAME_D9, DREAME_Z10_PRO]:
+    elif model in (
+        DREAME_F9,
+        DREAME_D9,
+        DREAME_Z10_PRO,
+        DREAME_MOP_2_PRO_PLUS,
+        DREAME_MOP_2_ULTRA,
+        DREAME_MOP_2,
+    ):
         return CleaningModeDreameF9
+    return None
 
 
 class DreameVacuumStatus(DeviceStatusContainer):
@@ -386,13 +406,7 @@ class DreameVacuumStatus(DeviceStatusContainer):
         return None
 
 
-class DreameVacuum(MiotDevice):
-    _supported_models = [
-        DREAME_1C,
-        DREAME_D9,
-        DREAME_F9,
-        DREAME_Z10_PRO,
-    ]
+class DreameVacuum(MiotDevice, VacuumInterface):
     _mappings = MIOT_MAPPING
 
     @command(
@@ -516,13 +530,22 @@ class DreameVacuum(MiotDevice):
         return self.set_property("cleaning_mode", fanspeed.value)
 
     @command()
-    def fan_speed_presets(self) -> Dict[str, int]:
-        """Return dictionary containing supported fan speeds."""
+    def fan_speed_presets(self) -> FanspeedPresets:
+        """Return available fan speed presets."""
         fanspeeds_enum = _get_cleaning_mode_enum_class(self.model)
         if not fanspeeds_enum:
             return {}
         return _enum_as_dict(fanspeeds_enum)
 
+    @command(click.argument("speed", type=int))
+    def set_fan_speed_preset(self, speed_preset: int) -> None:
+        """Set fan speed preset speed."""
+        if speed_preset not in self.fan_speed_presets().values():
+            raise ValueError(
+                f"Invalid preset speed {speed_preset}, not in: {self.fan_speed_presets().values()}"
+            )
+        self.set_fan_speed(speed_preset)
+
     @command()
     def waterflow(self):
         """Get water flow setting."""
@@ -609,3 +632,49 @@ class DreameVacuum(MiotDevice):
                 },
             ],
         )
+
+    @command(
+        click.argument("url", type=str),
+        click.argument("md5sum", type=str, required=False),
+        click.argument("size", type=int, default=0),
+        click.argument("voice_id", type=str, default="CP"),
+    )
+    def set_voice(self, url: str, md5sum: str, size: int, voice_id: str):
+        """Upload voice package.
+
+        :param str url: URL or path to language pack
+        :param str md5sum: MD5 hash for file if URL used
+        :param int size: File size in bytes if URL used
+        :param str voice_id: In original it is country code for the selected
+        voice pack. You can put here what you like, I guess it doesn't matter (default: CP - Custom Packet)
+        """
+        local_url = None
+        server = None
+        if url.startswith("http"):
+            if md5sum is None or size == 0:
+                click.echo(
+                    "You need to pass md5 and file size when using URL for updating."
+                )
+                return
+            local_url = url
+        else:
+            server = OneShotServer(file=url)
+            local_url = server.url()
+            md5sum = server.md5
+            size = len(server.payload)
+
+            t = threading.Thread(target=server.serve_once)
+            t.start()
+            click.echo(f"Hosting file at {local_url}")
+
+        params = [
+            {"piid": 3, "value": voice_id},
+            {"piid": 4, "value": local_url},
+            {"piid": 5, "value": md5sum},
+            {"piid": 6, "value": size},
+        ]
+        result_status = self.call_action("set_voice", params=params)
+        if result_status["code"] == 0:
+            click.echo("Installation complete!")
+
+        return result_status
