@@ -8,6 +8,7 @@ from miio.tests.dummies import DummyMiotDevice
 from ..dreamevacuum_miot import (
     DREAME_1C,
     DREAME_F9,
+    MIOT_MAPPING,
     ChargingState,
     CleaningModeDreame1C,
     CleaningModeDreameF9,
@@ -175,6 +176,10 @@ class TestDreame1CVacuum(TestCase):
         value = self.device.fan_speed()
         assert value == {"Medium": 2}
 
+    def test_set_fan_speed_preset(self):
+        for speed in self.device.fan_speed_presets().values():
+            self.device.set_fan_speed_preset(speed)
+
 
 @pytest.mark.usefixtures("dummydreamef9vacuum")
 class TestDreameF9Vacuum(TestCase):
@@ -248,3 +253,14 @@ class TestDreameF9Vacuum(TestCase):
     def test_waterflow(self):
         value = self.device.waterflow()
         assert value == {"Medium": 2}
+
+
+@pytest.mark.parametrize("model", MIOT_MAPPING.keys())
+def test_dreame_models(model: str):
+    DreameVacuum(model=model)
+
+
+def test_invalid_dreame_model():
+    vac = DreameVacuum(model="model.invalid")
+    fp = vac.fan_speed_presets()
+    assert fp == {}
