@@ -4,7 +4,7 @@ from unittest.mock import patch
 
 import pytest
 
-from miio import RoborockVacuum, Vacuum, VacuumStatus
+from miio import RoborockVacuum, VacuumStatus
 from miio.tests.dummies import DummyDevice
 
 from ..vacuum import (
@@ -329,14 +329,6 @@ class TestVacuum(TestCase):
             self.device.set_mop_intensity(MopIntensity.Intense)
 
 
-def test_deprecated_vacuum(caplog):
-    with pytest.deprecated_call():
-        Vacuum("127.1.1.1", "68ffffffffffffffffffffffffffffff")
-
-    with pytest.deprecated_call():
-        from miio.vacuum import ROCKROBO_S6  # noqa: F401
-
-
 class DummyVacuumS7(DummyVacuum):
     def __init__(self, *args, **kwargs):
         self._model = ROCKROBO_S7
