@@ -7,7 +7,7 @@ import math
 import os
 import pathlib
 import time
-from typing import Dict, List, Optional, Type, Union
+from typing import List, Optional, Type, Union
 
 import click
 import pytz
@@ -22,6 +22,7 @@ from miio.click_common import (
 )
 from miio.device import Device, DeviceInfo
 from miio.exceptions import DeviceException, DeviceInfoUnavailableException
+from miio.interfaces import FanspeedPresets, VacuumInterface
 
 from .vacuumcontainers import (
     CarpetModeStatus,
@@ -97,6 +98,14 @@ class FanspeedS7(FanspeedEnum):
     Turbo = 104
 
 
+class FanspeedS7_Maxv(FanspeedEnum):
+    Silent = 101
+    Standard = 102
+    Medium = 103
+    Turbo = 104
+    Max = 108
+
+
 class WaterFlow(enum.Enum):
     """Water flow strength on s5 max."""
 
@@ -114,7 +123,7 @@ class MopMode(enum.Enum):
 
 
 class MopIntensity(enum.Enum):
-    """Mop scrub intensity on S7."""
+    """Mop scrub intensity on S7 + S7MAXV."""
 
     Close = 200
     Mild = 201
@@ -130,6 +139,16 @@ class CarpetCleaningMode(enum.Enum):
     Ignore = 2
 
 
+class DustCollectionMode(enum.Enum):
+    """Auto emptying mode (S7 + S7MAXV only)"""
+
+    Smart = 0
+    Quick = 1
+    Daily = 2
+    Strong = 3
+    Max = 4
+
+
 ROCKROBO_V1 = "rockrobo.vacuum.v1"
 ROCKROBO_S4 = "roborock.vacuum.s4"
 ROCKROBO_S4_MAX = "roborock.vacuum.a19"
@@ -142,10 +161,13 @@ ROCKROBO_T7 = "roborock.vacuum.a11"  # cn s7
 ROCKROBO_T7S = "roborock.vacuum.a14"
 ROCKROBO_T7SPLUS = "roborock.vacuum.a23"
 ROCKROBO_S7_MAXV = "roborock.vacuum.a27"
+ROCKROBO_Q5 = "roborock.vacuum.a34"
+ROCKROBO_G10S = "roborock.vacuum.a46"
 ROCKROBO_S7 = "roborock.vacuum.a15"
 ROCKROBO_S6_MAXV = "roborock.vacuum.a10"
 ROCKROBO_E2 = "roborock.vacuum.e2"
 ROCKROBO_1S = "roborock.vacuum.m1s"
+ROCKROBO_C1 = "roborock.vacuum.c1"
 
 SUPPORTED_MODELS = [
     ROCKROBO_V1,
@@ -161,16 +183,25 @@ SUPPORTED_MODELS = [
     ROCKROBO_T7SPLUS,
     ROCKROBO_S7,
     ROCKROBO_S7_MAXV,
+    ROCKROBO_Q5,
+    ROCKROBO_G10S,
     ROCKROBO_S6_MAXV,
     ROCKROBO_E2,
     ROCKROBO_1S,
+    ROCKROBO_C1,
+]
+
+AUTO_EMPTY_MODELS = [
+    ROCKROBO_S7,
+    ROCKROBO_S7_MAXV,
 ]
 
 
-class RoborockVacuum(Device):
+class RoborockVacuum(Device, VacuumInterface):
     """Main class for roborock vacuums (roborock.vacuum.*)."""
 
     _supported_models = SUPPORTED_MODELS
+    _auto_empty_models = AUTO_EMPTY_MODELS
 
     def __init__(
         self,
@@ -539,39 +570,39 @@ class RoborockVacuum(Device):
         click.argument("cron"),
         click.argument("command", required=False, default=""),
         click.argument("parameters", required=False, default=""),
+        click.argument("timer_id", required=False, default=None),
     )
-    def add_timer(self, cron: str, command: str, parameters: str):
+    def add_timer(self, cron: str, command: str, parameters: str, timer_id: str):
         """Add a timer.
 
         :param cron: schedule in cron format
         :param command: ignored by the vacuum.
         :param parameters: ignored by the vacuum.
         """
-        import time
+        if not timer_id:
+            timer_id = str(int(round(time.time() * 1000)))
+        return self.send("set_timer", [[timer_id, [cron, [command, parameters]]]])
 
-        ts = int(round(time.time() * 1000))
-        return self.send("set_timer", [[str(ts), [cron, [command, parameters]]]])
-
-    @command(click.argument("timer_id", type=int))
-    def delete_timer(self, timer_id: int):
+    @command(click.argument("timer_id", type=str))
+    def delete_timer(self, timer_id: str):
         """Delete a timer with given ID.
 
-        :param int timer_id: Timer ID
+        :param str timer_id: Timer ID
         """
-        return self.send("del_timer", [str(timer_id)])
+        return self.send("del_timer", [timer_id])
 
     @command(
-        click.argument("timer_id", type=int), click.argument("mode", type=TimerState)
+        click.argument("timer_id", type=str), click.argument("mode", type=TimerState)
     )
-    def update_timer(self, timer_id: int, mode: TimerState):
+    def update_timer(self, timer_id: str, mode: TimerState):
         """Update a timer with given ID.
 
-        :param int timer_id: Timer ID
-        :param TimerStae mode: either On or Off
+        :param str timer_id: Timer ID
+        :param TimerState mode: either On or Off
         """
         if mode != TimerState.On and mode != TimerState.Off:
             raise DeviceException("Only 'On' or 'Off' are  allowed")
-        return self.send("upd_timer", [str(timer_id), mode.value])
+        return self.send("upd_timer", [timer_id, mode.value])
 
     @command()
     def dnd_status(self):
@@ -616,8 +647,8 @@ class RoborockVacuum(Device):
         return self.send("get_custom_mode")[0]
 
     @command()
-    def fan_speed_presets(self) -> Dict[str, int]:
-        """Return dictionary containing supported fan speeds."""
+    def fan_speed_presets(self) -> FanspeedPresets:
+        """Return available fan speed presets."""
 
         def _enum_as_dict(cls):
             return {x.name: x.value for x in list(cls)}
@@ -642,6 +673,8 @@ class RoborockVacuum(Device):
             fanspeeds = FanspeedE2
         elif self.model == ROCKROBO_S7:
             fanspeeds = FanspeedS7
+        elif self.model == ROCKROBO_S7_MAXV:
+            fanspeeds = FanspeedS7_Maxv
         else:
             fanspeeds = FanspeedV2
 
@@ -649,6 +682,15 @@ class RoborockVacuum(Device):
 
         return _enum_as_dict(fanspeeds)
 
+    @command(click.argument("speed", type=int))
+    def set_fan_speed_preset(self, speed_preset: int) -> None:
+        """Set fan speed preset speed."""
+        if speed_preset not in self.fan_speed_presets().values():
+            raise ValueError(
+                f"Invalid preset speed {speed_preset}, not in: {self.fan_speed_presets().values()}"
+            )
+        return self.send("set_custom_mode", [speed_preset])
+
     @command()
     def sound_info(self):
         """Get voice settings."""
@@ -788,6 +830,47 @@ class RoborockVacuum(Device):
             == "ok"
         )
 
+    @command()
+    def dust_collection_mode(self) -> Optional[DustCollectionMode]:
+        """Get the dust collection mode setting."""
+        self._verify_auto_empty_support()
+        try:
+            return DustCollectionMode(self.send("get_dust_collection_mode")["mode"])
+        except Exception as err:
+            _LOGGER.warning("Error while requesting dust collection mode: %s", err)
+            return None
+
+    @command(click.argument("enabled", required=True, type=bool))
+    def set_dust_collection(self, enabled: bool) -> bool:
+        """Turn automatic dust collection on or off."""
+        self._verify_auto_empty_support()
+        return (
+            self.send("set_dust_collection_switch_status", {"status": int(enabled)})[0]
+            == "ok"
+        )
+
+    @command(click.argument("mode", required=True, type=EnumType(DustCollectionMode)))
+    def set_dust_collection_mode(self, mode: DustCollectionMode) -> bool:
+        """Set dust collection mode setting."""
+        self._verify_auto_empty_support()
+        return self.send("set_dust_collection_mode", {"mode": mode.value})[0] == "ok"
+
+    @command()
+    def start_dust_collection(self):
+        """Activate automatic dust collection."""
+        self._verify_auto_empty_support()
+        return self.send("app_start_collect_dust")
+
+    @command()
+    def stop_dust_collection(self):
+        """Abort in progress dust collection."""
+        self._verify_auto_empty_support()
+        return self.send("app_stop_collect_dust")
+
+    def _verify_auto_empty_support(self) -> None:
+        if self.model not in self._auto_empty_models:
+            raise VacuumException("Device does not support auto emptying")
+
     @command()
     def stop_zoned_clean(self):
         """Stop cleaning a zone."""
@@ -929,7 +1012,7 @@ class RoborockVacuum(Device):
             callback=callback,
         )
 
-        @dg.resultcallback()
+        @dg.result_callback()
         @dg.device_pass
         def cleanup(vac: RoborockVacuum, *args, **kwargs):
             if vac.ip is None:  # dummy Device for discovery, skip teardown
