@@ -113,6 +113,8 @@ class VacuumStatus(DeviceStatus):
             17: "Zoned cleaning",
             18: "Segment cleaning",
             22: "Emptying the bin",  # on s7+, see #1189
+            23: "Washing the mop",  # on a46, #1435
+            26: "Going to wash the mop",  # on a46, #1435
             100: "Charging complete",
             101: "Device offline",
         }
@@ -434,14 +436,22 @@ class Timer(DeviceStatus):
         self.croniter = croniter(self.cron, start_time=localized_ts)
 
     @property
-    def id(self) -> int:
-        """ID which can be used to point to this timer."""
-        return int(self.data[0])
+    def id(self) -> str:
+        """Unique identifier for timer.
+
+        Usually a unix timestamp of when the timer was created, but it is not
+        guaranteed. For example, valetudo apparently allows using arbitrary strings for
+        this.
+        """
+        return self.data[0]
 
     @property
-    def ts(self) -> datetime:
-        """Pretty-printed ID (timestamp) presentation as time."""
-        return pretty_time(int(self.data[0]) / 1000)
+    def ts(self) -> Optional[datetime]:
+        """Timer creation time, if the id is a unix timestamp."""
+        try:
+            return pretty_time(int(self.data[0]) / 1000)
+        except ValueError:
+            return None
 
     @property
     def enabled(self) -> bool:
