@@ -187,11 +187,15 @@ class EncryptionAdapter(Adapter):
             lambda decrypted_bytes: decrypted_bytes[: decrypted_bytes.rfind(b"\x00")]
             if b"\x00" in decrypted_bytes
             else decrypted_bytes,
+            # fix double-oh values for 090615.curtain.jldj03, ##1411
+            lambda decrypted_bytes: decrypted_bytes.replace(
+                b'"value":00', b'"value":0'
+            ),
         ]
 
         for i, quirk in enumerate(decrypted_quirks):
-            decoded = quirk(decrypted).decode("utf-8")
             try:
+                decoded = quirk(decrypted).decode("utf-8")
                 return json.loads(decoded)
             except Exception as ex:
                 # log the error when decrypted bytes couldn't be loaded
