@@ -15,7 +15,7 @@ from .dummies import DummyDevice
 
 class DummyAirQualityMonitorV1(DummyDevice, AirQualityMonitor):
     def __init__(self, *args, **kwargs):
-        self.model = MODEL_AIRQUALITYMONITOR_V1
+        self._model = MODEL_AIRQUALITYMONITOR_V1
         self.state = {
             "power": "on",
             "aqi": 34,
@@ -85,7 +85,7 @@ class TestAirQualityMonitorV1(TestCase):
 
 class DummyAirQualityMonitorS1(DummyDevice, AirQualityMonitor):
     def __init__(self, *args, **kwargs):
-        self.model = MODEL_AIRQUALITYMONITOR_S1
+        self._model = MODEL_AIRQUALITYMONITOR_S1
         self.state = {
             "battery": 100,
             "co2": 695,
@@ -134,7 +134,7 @@ class TestAirQualityMonitorS1(TestCase):
 
 class DummyAirQualityMonitorB1(DummyDevice, AirQualityMonitor):
     def __init__(self, *args, **kwargs):
-        self.model = MODEL_AIRQUALITYMONITOR_B1
+        self._model = MODEL_AIRQUALITYMONITOR_B1
         self.state = {
             "co2e": 1466,
             "humidity": 59.79999923706055,
